intelmq.bots.parsers.malwarepatrol package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.malwarepatrol package

## Submodules

## intelmq.bots.parsers.malwarepatrol.parser_dansguardian module

intelmq.bots.parsers.malwarepatrol.parser_dansguardian.BOT

  alias of `intelmq.bots.parsers.malwarepatrol.parser_dansguardian.DansParserBot`

class intelmq.bots.parsers.malwarepatrol.parser_dansguardian.DansParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse the MalwarePatrol Dans Guardian feed

  parse(report)

    A generator yielding the single elements of the data.

    Comments, headers etc. can be processed here. Data needed by self.parse_line can be saved in self.tempdata (list).

    Default parser yields stripped lines. Override for your use or use an existing parser, e.g.:

        parse = ParserBot.parse_csv

    You should do that for recovering lines too.

      recover_line = ParserBot.recover_line_csv

  parse_line(row, report)

    A generator which can yield one or more messages contained in line.

    Report has the full message, thus you can access some metadata. Override for your use.

  sourcetime = None

## Module contents